Module executor

Module executor 

The Executor for the threadshare GStreamer plugins framework.

The threadshare’s Executor consists in a set of Contexts. Each Context is identified by a name and runs a loop in a dedicated thread. Users can use the Context to spawn Futures. Futures are asynchronous processings which allow waiting for resources in a non-blocking way. Examples of non-blocking operations are:

  • Waiting for an incoming packet on a Socket.
  • Waiting for an asynchronous Mutex lock to succeed.
  • Waiting for a time related Future.

Element implementations should use PadSrc & PadSink which provides high-level features.

Re-exports

pub use async_wrapper::Async;

Modules

async_wrapper
reactor
timer

Structs

Context
A threadshare runtime Context.
JoinHandle
TaskId

Functions

block_on
Blocks on future.
block_on_or_add_subtask
Blocks on future in one way or another if possible.
yield_now
Yields execution back to the runtime.

Type Aliases

SubTaskOutput