Module reactor

Module reactor 

Structs

AfterTimerId
Timer is guaranteed to fire after the expected time.
Readable
Future for Async::readable.
ReadableOwned
Future for Async::readable_owned.
RegularTimerId
Timer will fire in its time slice. This can happen before of after the expected time.
Writable
Future for Async::writable.
WritableOwned
Future for Async::writable_owned.