Context

Struct Context 

pub struct Context(/* private fields */);
A threadshare runtime Context.

The Context provides low-level asynchronous processing features to multiplex task execution on a single thread.

Element implementations should use PadSrc and PadSink which provide high-level features.

Implementations

Source

impl Context

pub fn acquire(context_name: &str, wait: Duration) -> Result<Self, Error>

pub fn downgrade(&self) -> ContextWeak

pub fn name(&self) -> &str

pub fn wait_duration(&self) -> Duration

pub fn is_context_thread() -> bool

Returns true if a Context is running on current thread.

pub fn current() -> Option<Context>

Returns the Context running on current thread, if any.

pub fn current_task() -> Option<(Context, TaskId)>

Returns the TaskId running on current thread, if any.

pub fn enter<'a, F, O>(&'a self, f: F) -> O
where F: FnOnce() -> O + Send + 'a, O: Send + 'a,

Executes the provided function relatively to this Context.

Useful to initialize i/o sources and timers from outside of a Context.

Panic

This will block current thread and would panic if run from the Context.

pub fn spawn<Fut>(&self, future: Fut) -> JoinHandle<Fut::Output>
where Fut: Future + Send + 'static, Fut::Output: Send + 'static,

pub fn spawn_and_unpark<Fut>(&self, future: Fut) -> JoinHandle<Fut::Output>
where Fut: Future + Send + 'static, Fut::Output: Send + 'static,

pub fn add_sub_task<T>(&self, task_id: TaskId, sub_task: T) -> Result<(), T>
where T: Future<Output = SubTaskOutput> + Send + 'static,

pub async fn drain_sub_tasks() -> SubTaskOutput