pub fn after(when: Instant) -> OneshotAfter ⓘExpand description
Creates a timer that emits an event once no sooner than the given time instant.
See at for details.
pub fn after(when: Instant) -> OneshotAfter ⓘCreates a timer that emits an event once no sooner than the given time instant.
See at for details.