delay_for_at_least

Function delay_for_at_least 

pub fn delay_for_at_least(delay: Duration) -> OneshotAfter 
Creates a timer that emits an event once after the given delay.

See delay_for for details. The event is guaranteed to be emitted no sooner than the expected delay has elapsed.