interval_after_at_least

Function interval_after_at_least 

pub fn interval_after_at_least(
    start: Instant,
    period: Duration,
) -> Result<IntervalAfter, IntervalError>
Creates a timer that emits events periodically, starting at start.

See interval_at for details. The events are guaranteed to be emitted no sooner than the expected instants.