interval_at_least

Function interval_at_least 

pub fn interval_at_least(
    period: Duration,
) -> Result<IntervalAfter, IntervalError>
Creates a timer that emits events periodically, starting as soon as possible.

Returns an error if period is zero.

See interval for details. The events are guaranteed to be emitted no sooner than the expected instants.