pub struct Oneshot { /* private fields */ }Expand description
A future that emits an event at the given time.
Oneshots are futures that resolve when the given time is reached.
When throttling is activated (i.e. when using a non-0 wait
duration in Context::acquire), timer entries are assigned to
the nearest time frame, meaning that the timer may fire
wait / 2 ms earlier or later than the expected instant.