pub struct PadSink(/* private fields */);Expand description
The PadSink which Elements must own.
Call downgrade if you need to clone the PadSink.
See the pad module documentation for a description of the model.
Implementations
Sourceimpl PadSink
impl PadSink
pub fn downgrade(&self) -> PadSinkWeak
pub fn as_ref(&self) -> PadSinkRef<'_>