pub struct PadSinkRef<'a> { /* private fields */ }Expand description
A PadSink to be used in handlers functions and Futures.
Call downgrade if you need to clone the PadSink.
See the pad module documentation for a description of the model.
Implementations
Sourceimpl PadSinkRef<'_>
impl PadSinkRef<'_>
pub fn downgrade(&self) -> PadSinkWeak