pub struct PadSinkWeak(/* private fields */);Expand description
A PadSink which can be moved in Handlers functions and Futures.
Call upgrade to use the PadSink.
See the pad module documentation for a description of the model.
Implementations
Sourceimpl PadSinkWeak
impl PadSinkWeak
pub fn upgrade(&self) -> Option<PadSinkRef<'_>>