pub struct PadSrcRef<'a> { /* private fields */ }Expand description
A PadSrc to be used in Handlers functions and Futures.
Call downgrade if you need to clone the PadSrc.
See the pad module documentation for a description of the model.
Implementations
Methods from Deref<Target = PadSrcInner>
pub fn gst_pad(&self) -> &Pad
pub async fn push(&self, buffer: Buffer) -> Result<FlowSuccess, FlowError>
pub async fn push_list( &self, list: BufferList, ) -> Result<FlowSuccess, FlowError>
pub async fn push_event(&self, event: Event) -> bool