pub struct PadSrcWeak(/* private fields */);Expand description
A PadSrc which can be moved in handlers functions and Futures.
Call upgrade to use the PadSrc.
See the pad module documentation for a description of the model.
Implementations