The Executor for the threadshare GStreamer plugins framework.
The threadshare’s Executor consists in a set of Contexts. Each Context is
identified by a name and runs a loop in a dedicated thread. Users can use the Context
to spawn Futures. Futures are asynchronous processings which allow waiting for resources
in a non-blocking way. Examples of non-blocking operations are:
- Waiting for an incoming packet on a Socket.
- Waiting for an asynchronous
Mutexlockto succeed. - Waiting for a time related
Future.
Element implementations should use PadSrc & PadSink which provides high-level features.
Re-exports
pub use async_wrapper::Async;
Modules
Structs
- Context
- A
threadshareruntimeContext. - Join
Handle - TaskId
Functions
- block_
on - Blocks on
future. - block_
on_ or_ add_ subtask - Blocks on
futurein one way or another if possible. - yield_
now - Yields execution back to the runtime.