pub fn block_on<Fut>(future: Fut) -> Fut::OutputExpand description
Blocks on future.
IO & time related Futures must be handled within their own Context.
Wait for the result using a JoinHandle or a channel.
The current thread is blocking and the passed in future is executed.
Panics
This function panics if called within a Context thread.