Structs
- After
Timer Id - Timer is guaranteed to fire after the expected time.
- Readable
- Future for
Async::readable. - Readable
Owned - Future for
Async::readable_owned. - Regular
Timer Id - Timer will fire in its time slice. This can happen before of after the expected time.
- Writable
- Future for
Async::writable. - Writable
Owned - Future for
Async::writable_owned.