pub fn at(when: Instant) -> Oneshot ⓘExpand description
Creates a timer that emits an event once at the given time instant.
When throttling is activated (i.e. when using a non-0 wait
duration in Context::acquire), timer entries are assigned to
the nearest time frame, meaning that the delay might elapse
wait / 2 ms earlier or later than the expected instant.
Use after when it’s preferable not to return
before the expected instant.