pub fn interval_at(
start: Instant,
period: Duration,
) -> Result<Interval, IntervalError>Expand description
Creates a timer that emits events periodically, starting at start.
When throttling is activated (i.e. when using a non-0 wait
duration in Context::acquire), timer entries are assigned to
the nearest time frame, meaning that the delay might elapse
wait / 2 ms earlier or later than the expected instant.
Use interval_after_at_least when it’s preferable not to tick
before the expected instants.