pub struct Task(/* private fields */);Expand description
A Task operating on a threadshare Context.
Implementations
Sourceimpl Task
impl Task
pub fn state(&self) -> TaskState
pub fn lock_state(&self) -> TaskStateGuard<'_>
pub fn prepare( &self, task_impl: impl TaskImpl, context: Context, ) -> TransitionStatus ⓘ
pub fn unprepare(&self) -> TransitionStatus ⓘ
Sourcepub fn start(&self) -> TransitionStatus ⓘ
pub fn start(&self) -> TransitionStatus ⓘ
Starts the Task.
The execution occurs on the Task context.
Sourcepub fn pause(&self) -> TransitionStatus ⓘ
pub fn pause(&self) -> TransitionStatus ⓘ
Requests the Task loop to pause.
If an item handling is in progress, it will run to completion,
then no iterations will be executed before start is called again.
pub fn flush_start(&self) -> TransitionStatus ⓘ
pub fn flush_stop(&self) -> TransitionStatus ⓘ
Sourcepub fn stop(&self) -> TransitionStatus ⓘ
pub fn stop(&self) -> TransitionStatus ⓘ
Stops the Started Task and wait for it to finish.